Structs
- Byte
Stream Info - Information about a byte data stream.
- Byte
Stream Reader - Reader for an incoming byte data stream.
- Byte
Stream Writer - Writer for an open byte data stream.
- Stream
Byte Options - Options used when opening an outgoing byte data stream.
- Stream
Text Options - Options used when opening an outgoing text data stream.
- Text
Stream Info - Information about a text data stream.
- Text
Stream Reader - Reader for an incoming text data stream.
- Text
Stream Writer - Writer for an open text data stream.
Enums
- Operation
Type - Operation type for text streams.
- Stream
Error - Error type for data stream operations.
Traits
- Stream
Reader - Reader for an incoming data stream.
- Stream
Writer - Writer for an open data stream.
Type Aliases
- Stream
Result - Result type for data stream operations.