pub struct RpcError {
pub code: u32,
pub message: String,
pub data: Option<String>,
}Expand description
Specialized error handling for RPC methods.
Instances of this type, when thrown in a method handler, will have their message
serialized and sent across the wire. The caller will receive an equivalent error on the other side.
Build-in types are included but developers may use any string, with a max length of 256 bytes.
Fields
code: u32message: Stringdata: Option<String>Implementations
Sourceimpl RpcError
impl RpcError
pub const MAX_MESSAGE_BYTES: usize = 256
pub const MAX_DATA_BYTES: usize = 15360
Sourcepub fn new(code: u32, message: String, data: Option<String>) -> Self
pub fn new(code: u32, message: String, data: Option<String>) -> Self
Creates an error object with the given code and message, plus an optional data payload.
If thrown in an RPC method handler, the error will be sent back to the caller.
Error codes 1001-1999 are reserved for built-in errors (see RpcErrorCode for their meanings).
pub fn from_proto(proto: RpcError_Proto) -> Self
pub fn to_proto(&self) -> RpcError_Proto