pub struct RpcInvocationData {
pub request_id: String,
pub caller_identity: ParticipantIdentity,
pub payload: String,
pub response_timeout: Duration,
}Expand description
Data passed to method handler for incoming RPC invocations
Attributes: request_id (String): The unique request ID. Will match at both sides of the call, useful for debugging or logging. caller_identity (ParticipantIdentity): The unique participant identity of the caller. payload (String): The payload of the request. User-definable format, typically JSON. response_timeout (Duration): The maximum time the caller will wait for a response.
Fields
request_id: Stringcaller_identity: ParticipantIdentitypayload: Stringresponse_timeout: DurationTrait Implementations
Sourceimpl Clone for RpcInvocationData
impl Clone for RpcInvocationData
Sourcefn clone(&self) -> RpcInvocationData
fn clone(&self) -> RpcInvocationData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for RpcInvocationData
impl RefUnwindSafe for RpcInvocationData
impl Send for RpcInvocationData
impl Sync for RpcInvocationData
impl Unpin for RpcInvocationData
impl UnsafeUnpin for RpcInvocationData
impl UnwindSafe for RpcInvocationData