TakeCell

Struct TakeCell 

pub struct TakeCell<T> { /* private fields */ }
A thread-safe cell that holds a value which can be taken exactly once. After taking the value, subsequent attempts to take it will return None.

Implementations

Source

impl<T> TakeCell<T>
where T: StreamReader,

pub fn take_if(&self, predicate: impl FnOnce(&T::Info) -> bool) -> Option<T>

Takes the reader out of the cell if its info matches the given predicate.

Use this method to conditionally handle incoming streams based on info fields such as topic or attributes.

This method will only take the reader if the provided predicate returns true when called with the reader’s info. If the predicate returns false or the reader has already been taken, this method returns None.

Source

impl<T> TakeCell<T>

pub fn take(&self) -> Option<T>

Take ownership of the value in the cell. If the value has, already been taken, the result is None.

pub fn is_taken(&self) -> bool

Returns whether or not the value has been taken.